@@ -2,11 +2,9 @@
 #define EPSFUNCTION
 //====================================================
 #include <stdio.h>
-#include <GL/glut.h>
 #include <tulip/Color.h>
+#include <GL/gl.h>
 
-void SetColor(const Color &C);
-void SetMaterial(const Color &C);
 void Line(float x1,float y1,float z1,float x2, float y2 ,  float z2, Color C1, Color C2);
 void Rect(float x, float y , float z, float w , float h);
 GLfloat *spewPrimitiveEPS(FILE * file, GLfloat * loc);
