@@ -2,11 +2,10 @@
 #define _FONTS_H_
 
 #include <string>
+enum FontMode{TLP_BITMAP, TLP_PIXMAP, TLP_OUTLINE, TLP_POLYGON, TLP_EXTRUDE, TLP_TEXTURE, TLP_TLPPIXMAP};
 
-typedef enum FontMode{BITMAP, PIXMAP, OUTLINE, POLYGON, EXTRUDE, TEXTURE, TLPPIXMAP};
-
-class Fonts{
-  friend class Rendu;
+class Fonts {
+  friend class TextRenderer;
 
  public:
   virtual void drawString(const std::string str, int indice=-1)const=0;
