@@ -2,7 +2,7 @@
 /**
  Author: David Auber
  Email : auber@labri.fr
- Last modification : 20/08/2001
+ Last modification : 06/09/2005
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by  
  the Free Software Foundation; either version 2 of the License, or     
@@ -43,9 +43,9 @@
 #include <tulip/hash_string.h>
 #include <tulip/tulipconf.h>
 #include "tulip/Camera.h"
-#include "tulip/GlGraphStrategy.h"
 #include "tulip/OcclusionTest.h"
 #include "tulip/ObservableGlGraph.h"
+#include <tulip/Matrix.h>
 
 
 class LayoutProxy;
@@ -64,9 +64,12 @@ class OcclusionTest;
 class PluginLoader;
 class TextRenderer;
 
-enum DrawState {DRAWEDGE = 0, DRAWNODE = 1, DRAWSELECTEDNODELABELS = 2, DRAWSELECTEDEDGELABELS = 3,
+
+enum DrawState { DRAWNODE = 0, DRAWEDGE = 1, DRAWSELECTEDNODELABELS = 2, DRAWSELECTEDEDGELABELS = 3,
 		DRAWNODELABELS = 4 , DRAWEDGELABELS = 5 , DRAWEND = 6};
 
+enum EdgeShape {POLYLINESHAPE = 0, BEZIERSHAPE = 4, SPLINESHAPE = 8};
+
 /**
  * This widget enables an incremental 3D drawing of a Tulip SuperGraph.
  *  It also includes 3D navigation capabilities and selection methods.
@@ -75,8 +78,8 @@ enum DrawState {DRAWEDGE = 0, DRAWNODE = 1, DRAWSELECTEDNODELABELS = 2, DRAWSELE
 class TLP_GL_SCOPE GlGraph : public GraphObserver, public ObservableGlGraph {
   
 public:
-  GlGraph(GlGraphStrategy &strategy);
-  GlGraph(GlGraphStrategy &strategy, const GlGraph &);
+  GlGraph();
+  GlGraph(const GlGraph &);
   ~GlGraph();
   //============================================
   /**
@@ -86,7 +89,7 @@ public:
   void initializeGL();
   //============================================
   DataSet getParameters() const;
-  void setParameters(const DataSet);
+  void    setParameters(const DataSet);
   /**
    *  Initialize scale factors according to layout bounding box
    *  and the camera position in order to have the graph at the 
@@ -111,7 +114,7 @@ public:
   /**
    * copy current values into given parameters (names are corresponding)
    */
-  void getWinParameters(int *winX, int *winY, int *winW, int *winH, GLint *vp[4]);
+  virtual void getWinParameters(int *winX, int *winY, int *winW, int *winH, GLint *vp[4]);
   //==============================================================================
   // Data centralization in order to optimize memory using
   //==============================================================================
@@ -172,6 +175,15 @@ public:
    * \sa setEdgeColorInterpolate
    */
   bool isEdgeColorInterpolate() const;
+  /** activate or deactivate interpolation of nodes colors along edge
+   *  \sa isEdgeColorInterpolate
+   */
+  void setEdgeSizeInterpolate(const bool state);
+  /** return true if color interpolation is activated
+   * \sa setEdgeColorInterpolate
+   */
+  bool isEdgeSizeInterpolate() const;
+
   /** return the type of fonts used in the renderer(0=3D,1=bitmap,2=texture)
    *  \sa setFontsType
    */
@@ -269,7 +281,7 @@ public:
   void zoom(const int step);
   /** \brief zoom to  screen coordinates
    *  a translation is performed while zooming. The farther the point (x,y) is
-   *  from the center of the screen, the bigger is the translation. The direction
+   *  from the center of the screen, the higher the translation is. The direction
    *  of the translation is reversed when switching from zoom in to zoom out.
    *  \sa zoom
    */
@@ -284,44 +296,23 @@ public:
    *  \param sNode filled by the method with the nodes found in the region
    *  \param sEdge filled by the method with the edges found in the region
    */
-  void doSelect(const int x, const int y, const int width, const int height, std::set<node> &sNode, std::set<edge> &sEdge);
+  void doSelect(const int x, const int y, const int width, const int height, std::vector<node> &sNode, std::vector<edge> &sEdge);
    /** \brief select a node or edge at a point
-   *
-   *  select either a node or edge at point (x,y)
-   *  \param type tells what has been found: NODE, EDGE
-   *  \return true if something has been found, false otherwise
-   */
+    *  select either a node or edge at point (x,y)
+    *  \param type tells what has been found: NODE, EDGE
+    *  \return true if something has been found, false otherwise
+    */
   bool doSelect(const int x, const int y, tlp::ElementType &type, node &, edge &);
   /** \brief select nodes in a region of the screen
-   *
-   *  select all nodes lying in the area of the screen of given width and height,
-   *  and with its upper-left corner at (x,y)
-   *  \param sNode filled by the method with the nodes found in the region
-   *  \return true if at least one node has been found
-   *  \sa doSelect(const int, const int, const int, const int, set<node>&, set<edge>&),
-          doEdgeSelect(const int, const int, const int, const int, set<edge>&);
-   */
-  bool doNodeSelect(const int x, const int y, const int w, const int h, std::set<node> &sNode);
-  /** \brief select nodes in a region of the screen
-   *
-   *  select all edges lying in the area of the screen of given width and height,
-   *  and with its upper-left corner at (x,y)
-   *  \param sEdge filled by the method with the edges found in the region
-   *  \return true if at least one edge has been found
-   *  \sa doSelect(const int, const int, const int, const int, set<node>&, set<edge>&),
-          doNodeSelect(const int, const int, const int, const int, set<node>&);      
-   */
-  bool doEdgeSelect(const int x, const int y, const int w, const int h, std::set<edge> &sEdge);
-  /** select nodes at a given point, ordered from the closest to the farthest
    *  \param selected the nodes found
    *  \return true if at least one node has been found
    */
-  bool doNodeSelect(const int x, const int y, std::vector<node> &selected);
+  bool doNodeSelect(const int x, const int y, const int width, const int height, std::vector<node> &selected, const bool ordered = true);
   /** select edges at a given point, ordered from the closest to the farthest
    *  \param selected the edges found
    *  \return true if at least one edge has been found
    */
-  bool doEdgeSelect(const int x, const int y, std::vector<edge> &selected);
+  bool doEdgeSelect(const int x, const int y, const int width, const int height, std::vector<edge> &selected, const bool ordered = true);
   //=======================================================================
   //Tools
   //=======================================================================
@@ -331,7 +322,12 @@ public:
    * Compute coordinate from the 2D screen space to the 
    * 3D space.
    */
-  void screenTo3DWorld(double& x, double& y, double& z);
+  void screenTo3DWorld(float& x, float& y, float& z);
+  /**
+   * Compute coordinate from the 3D space to the 
+   * 2D screen space.
+   */
+  void worldTo2DScreen(float& x, float& y, float& z);
   /** 
    *  Take a snapshot of the Open GL windows
    *  \return an array of dimension width*height*3 char (8bits per color RGB).
@@ -367,10 +363,20 @@ public:
    */
   void setInputLayout(const std::string &layoutName);
 
-  static TemplateFactory<GlyphFactory,Glyph,GlyphContext *> glyphFactory;
+  static TemplateFactory<GlyphFactory,Glyph,GlyphContext *> *glyphFactory;
+  static TLP_GL_SCOPE void initFactory() {
+    if (!glyphFactory) {
+      glyphFactory = new TemplateFactory<GlyphFactory,Glyph,GlyphContext *>;
+      glyphFactory->currentLoader = 0;
+    }
+  }
   static std::string glyphName(int id);
-  static int glyphId(std::string name);
+  static int  glyphId(std::string name);
   static void loadPlugins(PluginLoader *plug=0);
+  static std::string edgeShapeName(int id);
+  static int edgeShapeId(std::string name);
+  static const int edgeShapesCount;
+  static int edgeShapeIds[];
 
 private:
   static stdext::hash_map<int,std::string>  idToName;
@@ -382,8 +388,7 @@ protected:
   void delNode (SuperGraph *, const node);
   void delEdge (SuperGraph *, const edge);
   void destroy (SuperGraph *);
-  float projectSize(const Coord&, const Size&);
-  void drawPixmapFont(const std::string &str, const Coord &position, bool selected, float width);
+  void drawPixmapFont(const std::string &str, const Color &col, const Coord &position, bool selected, float width);
   void drawEdge(const Coord &startNode, const Coord &finalNode,
                 const Coord &startPoint,const LineType::RealType &bends, const Coord &endPoint,
 		const Color &startColor, const Color &endColor, const Size &size, int shape, const bool selected=false);
@@ -421,12 +426,13 @@ protected:
 
 
 private:
-  GlGraphStrategy *strategy;
+  // GlGraphStrategy *strategy;
   SuperGraph     *_superGraph;
   Color  backgroundColor;
 
   bool _viewArrow, _viewLabel, _viewMetaLabel, _viewStrahler;
   bool _viewAutoScale, _incrementalRendering, _edgeColorInterpolate, _edge3D;
+  bool _edgeSizeInterpolate;
   unsigned int _viewOrtho;
   unsigned int _FontsType;
   std::string fontsPath;
@@ -441,13 +447,16 @@ private:
   GLint viewportArray[4];
   GLdouble modelviewMatrix[16];
   GLdouble projectionMatrix[16];
+  GLdouble transformMatrix[16];
 
 
   //FIXME: made public to allow glyphs to access those proxy
 public:
   ColorsProxy    *elementColor;
+  ColorsProxy    *elementLabelColor;
   SizesProxy     *elementSize;
   IntProxy       *elementShape;
+  MetricProxy    *elementRotation;
   SelectionProxy *elementSelected;
   StringProxy    *elementLabel;
   LayoutProxy    *elementLayout;
@@ -458,14 +467,11 @@ private:
 
   //we never have to get a copy of that GlGraph.
   //GlGraph objects should be only passed by reference or pointer
-  GlGraph(const GlGraph &);
   static void loadPlugins(std::string dir, PluginLoader *plug);
 
 private:
 
-  GLint vp[4]; //->getGetIntegerv(GL_VIEWPORT)
   GLuint (*selectBuf)[4];
-
   //predefined display list
   GLuint metaGraphDL;
   GLuint selectionDL;
@@ -476,8 +482,8 @@ private:
   Coord sceneTranslation; // Scene translation
   Coord sceneRotation; // Rotation of the scene
   //Camera information
-  Coord cameraEyes,cameraCenter,cameraUp;
-  double cameraZoomFactor;
+  Coord   cameraEyes,cameraCenter,cameraUp;
+  double  cameraZoomFactor;
   GLfloat distCam;   //distance for camera translation
   //viewport position and size
   unsigned int winX, winY; 
@@ -500,6 +506,7 @@ private:
 
   //
   MutableContainer<unsigned int> nbElementsFrame;
+  MutableContainer<bool> nodesRenderedAsPoint;
   unsigned int currentFrame;
   unsigned drawState;
   unsigned int labelsBorder;
@@ -510,6 +517,23 @@ private:
   //
   std::string layoutName;
   TextRenderer * fontRenderer;
+
+  //----------------------------
+  // from GlGraphStrategy
+  //----------------------------
+public: 
+  //GlGraph has to call this before any GL operation
+  virtual void makeCurrent()=0;
+  virtual void updateGL()=0;
+
+  //timer methods
+  virtual bool timerIsActive()=0;
+  virtual int timerStart(int msec, bool sshot=false)=0;
+  virtual void timerStop()=0;
+
+  virtual void mPaint()=0;
+
+  bool toUpdate;
 };
 
 
