@@ -9,6 +9,10 @@ class SelectionProxy;
 #include <tulip/Node.h>
 #include <tulip/Edge.h>
 
+#if (QT_REL == 4)
+#include "tulip/Qt3ForTulip.h"
+#endif
+
 #include "FindSelectionData.h"
 
 struct TLP_QT_SCOPE GItem {
@@ -22,8 +26,8 @@ struct TLP_QT_SCOPE GItem {
 class TLP_QT_SCOPE SelectionWidget : FindSelection {
   Q_OBJECT
     public:
-  SelectionWidget::SelectionWidget(SuperGraph *superGraph, QWidget *parent = 0, const char *name = 0,
-				   WFlags fl = 0);
+  SelectionWidget(SuperGraph *superGraph, QWidget *parent = 0, const char *name = 0,
+		  Qt::WFlags fl = 0);
   int exec();
 
  private:
