@@ -1,3 +1,5 @@
+#if (QT_REL == 3)
+
 #include <iostream>
 
 #include <qstringlist.h>
@@ -106,3 +108,5 @@ bool TulipWidgetsPlugin::isContainer(const QString& feature) const {
 }
 
 Q_EXPORT_PLUGIN(TulipWidgetsPlugin);
+
+#endif
