@@ -6,26 +6,19 @@
 class Size : public tlp::Vector<float,3> {
 public:
   inline Size(const float width=0,const float height=0,const float depth=0);
-  ///
+  inline Size(const tlp::Vector<float,3> &);
   inline void set(const float width=0,const float height=0,const float depth=0);
-  ///
   inline void set(const Size& size);
-  ///
   inline void setW(const float width);
-  ///
   inline void setH(const float height);
-  ///
   inline void setD(const float depth);
-  ///
   inline float getW() const;
-  ///
   inline float getH() const;
-  ///
   inline float getD() const;
-  ///
   inline void get(float &width, float &height, float &depth) const;
 };
 
+Size::Size(const tlp::Vector<float,3> &v) : tlp::Vector<float,3>(v) {}
 Size::Size(const float width,const float height,const float depth) {
   array[0]=width;
   array[1]=height;
@@ -49,5 +42,4 @@ void Size::setW(const float width) {array[0]=width;}
 void Size::setH(const float height) {array[1]=height;}
 void Size::setD(const float depth) {array[2]=depth;}
 
-
 #endif
