@@ -3,7 +3,7 @@
 #include <tulip/AcyclicTest.h>
 #include "DagLevelMetric.h"
 
-METRICPLUGIN(DagLevelMetric,"DagLevel","David Auber","10/03/2000","Alpha","0","1");
+METRICPLUGINOFGROUP(DagLevelMetric,"DagLevel","David Auber","10/03/2000","Alpha","0","1","Tree");
 
 using namespace std;
 
@@ -55,18 +55,3 @@ bool DagLevelMetric::check(string &erreurMsg) {
     return false;
   }
 }
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
